@@ -112,10 +112,9 @@ private slots:
     void slotRemoveMenu(const QString &menu);
     void slotSystrayEnable();
 
-private:
-    bool hasChanged();
-    bool isDefault();
-    bool isValidKeyserver(const QString &);
+protected:
+    virtual bool hasChanged();
+    virtual bool isDefault();
 
 private:
     QStringList names;
@@ -123,7 +122,6 @@ private:
     QString alwaysKeyID;
     QString fileEncryptionKey;
     QString gpgConfigPath;
-    QString gpgBinPath;
     QString keyServer;              // Server stored in GnuPG config
     QStringList serverList;         // Servers stored in kgpgrc
     QString defaultKeyServer;       // Default keyserver
@@ -141,15 +139,16 @@ private:
     QColor keyUnknown;
     QColor keyRev;
 
-    KFontChooser *m_fontchooser;
     KConfig *m_config;
 
-    Encryption *m_page1;
-    Decryption *m_page2;
-    UIConf *m_page3;
-    GPGConf *m_page4;
-    ServerConf *m_page6;
-    MiscConf *m_page7;
+    Encryption * const m_page1;
+    Decryption * const m_page2;
+    UIConf * const m_page3;
+    GPGConf * const m_page4;
+    ServerConf * const m_page6;
+    MiscConf * const m_page7;
+
+    KFontChooser * const m_fontchooser;
 
     bool m_useagent;
     bool m_defaultuseagent;
@@ -161,6 +160,8 @@ private:
 
     KGpgItemModel * const m_model;
     KeyListProxyModel * const m_combomodel;
+
+    bool isValidKeyserver(const QString &);
 };
 
 #endif // KGPGOPTIONS_H
